import { Matrix4, Vector3 } from 'three';
import { ApplicationService } from '../ApplicationServices/Application';
import { InputState } from '../Common/InputState';
import { Entity } from '../DatabaseServices/Entity/Entity';
import { CommandInputManage } from '../UI/Components/CommandInput/CommandInputManage';
import { MaskManage } from '../UI/Components/Modal/MaskManage';
import { CommandStore } from '../UI/Store/CommandStore';
import { ContextMenuServices } from './ContextMenu';
import { GetDistanceServices } from './GetDistanceServices';
import { GetEntityServices } from './GetEntityServices';
import { GetKeyWordsServices } from './GetKeyWordService';
import { GetPointServices } from './GetPointServices';
import { GetRectPointServices } from './GetRectServices';
import { SsgetServiecs } from './GetSelectionServices';
import { GetStringService } from './GetStringService';
import { GripDragServices } from './GripDragServices';
import { KeyBoardControls } from './KeyBoardControls';
import { MouseControls } from './MouseControls';
import { GetDistendPrompt, GetEntityPrompt, GetKeyWordPrommpt, GetPointPrompt, GetSelectionPrompt, GetStringPrompt, PromptRectPointOptions } from "./PromptOptions";
import { PromptDistendResult, PromptEntityResult, PromptPointResult, PromptRectResult, PromptResult, PromptSsgetResult } from './PromptResult';
import { SelectControls } from './SelectControls';
import { TransformServicess } from './TranstrolControl/TransformServices';
import { UCSServices } from './UCSServices';
import { ModalManage } from '../UI/Components/Modal/ModalsManage';
export declare class Editor {
    MouseCtrl: MouseControls;
    KeyCtrl: KeyBoardControls;
    SelectCtrl: SelectControls;
    App: ApplicationService;
    InputState: InputState;
    CommandStore: CommandStore;
    GetPointServices: GetPointServices;
    GetDistanceServices: GetDistanceServices;
    GetRectPointServices: GetRectPointServices;
    GetEntitytServices: GetEntityServices;
    SnapDragServices: GripDragServices;
    transCtrl: TransformServicess;
    UcsServices: UCSServices;
    MaskManage: MaskManage;
    ModalManage: ModalManage;
    CommandInput: CommandInputManage;
    SsgetServices: SsgetServiecs;
    KeywordsServices: GetKeyWordsServices;
    ContextMenuServices: ContextMenuServices;
    InteractiveServices: EditorService[];
    GetStringService: GetStringService;
    constructor(app: ApplicationService);
    /**
     * 在命令行输出一行提示信息.
     */
    Prompt(msg: string): void;
    get UCSMatrix(): Matrix4;
    get UCSMatrixInv(): Matrix4;
    set UCSMatrix(m: Matrix4);
    SetUCSLookAt(viewDir: Vector3): void;
    InputEvent(inputData: string): void;
    Canel(): void;
    GetPoint(prompt?: GetPointPrompt): Promise<PromptPointResult>;
    GetDistance(prompt?: GetDistendPrompt): Promise<PromptDistendResult>;
    GetRectPoint(prompt?: PromptRectPointOptions): Promise<PromptRectResult>;
    GetAngle(prompt?: GetDistendPrompt): Promise<PromptDistendResult>;
    GetKeyWords(prompt: GetKeyWordPrommpt): Promise<PromptResult>;
    GetString(prompt: GetStringPrompt): Promise<PromptResult>;
    GetEntity(prompt?: GetEntityPrompt): Promise<PromptEntityResult>;
    GetSelection(prompt?: GetSelectionPrompt): Promise<PromptSsgetResult>;
    PointToScreen(pt: THREE.Vector3): THREE.Vector2;
    SelectWindow(p1: THREE.Vector3, p2: THREE.Vector3): Array<Entity>;
    SelectAll(): Array<Entity>;
    RemoveSelect(ent: Entity): void;
    UpdateScreen(): void;
}
export interface EditorService {
    IsReady: boolean;
    Doit: (e: MouseEvent) => Promise<boolean>;
    Cancel: () => void;
}
//# sourceMappingURL=Editor.d.ts.map